.. hckr documentation master file, created by
   sphinx-quickstart on Wed Jun 12 20:06:39 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

:layout: landing
:description: ``hckr`` is a modern, command line utililty for developers,

👋 Hi, welcome to hckr
======================

.. rst-class:: lead

``hckr`` is a command line utililty for developers. Support us by starring on Github and contributing 🙏

.. container:: buttons

    :ref:`Docs <installation>`
    `GitHub <https://github.com/hckr-cli/hckr>`_


.. toctree::
   :maxdepth: 2
   :caption: Getting started
   :hidden:

   setup/index

.. toctree::
   :maxdepth: 2
   :caption: Commands
   :hidden:

   commands/index

